#include <stdexcept>

#include "seq.hpp"

const Alphabet& SeqString::get_alphabet() const
{
  return Alphabet::get_alphabet(alphabet);
}

std::string SeqString::create_reverse_complement_map() const 
{
  std::string rc_map(256, '~');
  // if we're rna, use U instead of T
  // we might want to add an "is_rna" to sequence at somepoint
  char TU = (alphabet == reduced_rna_alphabet) ? 'U' : 'T';
  char tu = (alphabet == reduced_rna_alphabet) ? 'u' : 't';
  rc_map['A'] = TU ; rc_map['a'] = tu ;
  rc_map['T'] = 'A'; rc_map['t'] = 'a';
  rc_map['U'] = 'A'; rc_map['u'] = 'a';
  rc_map['G'] = 'C'; rc_map['g'] = 'c';
  rc_map['C'] = 'G'; rc_map['c'] = 'g';
  rc_map['M'] = 'K'; rc_map['m'] = 'k';
  rc_map['R'] = 'Y'; rc_map['r'] = 'y';
  rc_map['W'] = 'W'; rc_map['w'] = 'w';
  rc_map['S'] = 'S'; rc_map['s'] = 's';
  rc_map['Y'] = 'R'; rc_map['y'] = 'r';
  rc_map['K'] = 'M'; rc_map['k'] = 'm';
  rc_map['V'] = 'B'; rc_map['v'] = 'b';
  rc_map['H'] = 'D'; rc_map['h'] = 'd';
  rc_map['D'] = 'H'; rc_map['d'] = 'h';
  rc_map['B'] = 'V'; rc_map['b'] = 'v';  
  rc_map['N'] = 'N'; rc_map['n'] = 'n';
  rc_map['X'] = 'X'; rc_map['x'] = 'x';
  rc_map['?'] = '?'; 
  rc_map['.'] = '.'; 
  rc_map['-'] = '-'; 
  rc_map['~'] = '~'; // not really needed, but perhaps it's clearer.
   
  return rc_map;
}
