#include "qui/seqbrowser/seqproperties/PropertiesWindow.hpp"

#include "mussa_exceptions.hpp"
#include "alg/mussa.hpp"

#include <QMessageBox>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QGridLayout>

PropertiesWindow::PropertiesWindow(/* MussaRef m, */
                                   SequencePropertiesModel::model_type glseqs,
                                   QWidget *parent)
  : QWidget(parent),
    /* analysis(m), */
    table(0),
    applyButton(0),
    closeButton(0),
    model(glseqs)
{
  QGridLayout *parameterLayout = new QGridLayout;

  applyButton = new QPushButton(tr("&Apply"), this);
  applyButton->setFocusPolicy(Qt::StrongFocus);
  applyButton->setEnabled( not model.empty() );
  connect(applyButton, SIGNAL(clicked()), this, SLOT(apply()));

  closeButton = new QPushButton(tr("Close"), this);
  connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));

  table = new QTableView(this);
  table->setModel(&model);

  // layout buttons
  QHBoxLayout *buttonLayout = new QHBoxLayout;
  buttonLayout->addWidget(applyButton);
  buttonLayout->addWidget(closeButton);

  // layout verticle space
  QVBoxLayout *verticalLayout = new QVBoxLayout;
  verticalLayout->addWidget(table);
  verticalLayout->addLayout(buttonLayout);
  setLayout(verticalLayout);

  // now that we're all setup lets get notices when we're updated
  connect(&model, SIGNAL(rowsInserted(const QModelIndex&, int, int)), 
          this, SLOT(modelUpdated(const QModelIndex&, int, int)));
  connect(&model, SIGNAL(rowsRemoved(const QModelIndex&, int, int)), 
          this, SLOT(modelUpdated(const QModelIndex&, int, int)));
          
  updateTitle();        
}

SequencePropertiesModel& PropertiesWindow::getModel()
{
  return model;
}

void PropertiesWindow::close()
{
  model.clear();
  hide();
}

void PropertiesWindow::apply()
{
  model.saveChanges();
  emit propertiesChanged();
}

void PropertiesWindow::modelUpdated(const QModelIndex&, int, int )
{
  // if the model is empty we shouldn't be able to click ok
  if (applyButton) applyButton->setEnabled(not model.empty());
}

void PropertiesWindow::updateTitle()
{
  std::string title("Sequence Properites: ");
  if (analysis) {
    title += analysis->get_title();
  }
  setWindowTitle(title.c_str());  
}
